@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.42.0"
+version = "1.49.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,11 +27,12 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.9-r1",
+apk_tools_min_version = {"edge": "2.12.10-r1",
+                         "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
                          "v3.13": "2.12.7-r0",
-                         "v3.12": "2.10.8-r0"}
+                         "v3.12": "2.10.8-r1"}
 
 # postmarketOS aports compatibility (checked against "version" in pmaports.cfg)
 pmaports_min_version = "7"
@@ -50,7 +51,12 @@ ondev_min_version = "0.2.0"
 # Programs that pmbootstrap expects to be available from the host system. Keep
 # in sync with README.md, and try to keep the list as small as possible. The
 # idea is to run almost everything in Alpine chroots.
-required_programs = ["git", "openssl", "ps"]
+required_programs = [
+    "git",
+    "openssl",
+    "ps",
+    "tar",
+]
 sudo = which_sudo()
 
 # Keys saved in the config file (mostly what we ask in 'pmbootstrap init')
@@ -261,7 +267,7 @@ chroot_outdated = 3600 * 24 * 2
 # specify architectures supported by Alpine here. For cross-compiling,
 # we need to generate the "musl-$ARCH", "binutils-$ARCH" and "gcc-$ARCH"
 # packages (use "pmbootstrap aportgen musl-armhf" etc.).
-build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86"]
+build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86", "riscv64"]
 
 # Packages that will be installed in a chroot before it builds packages
 # for the first time
@@ -328,18 +334,17 @@ necessary_kconfig_options = {
     }
 }
 
-# Necessary anbox/waydroid kernel config options (android app support)
-necessary_kconfig_options_anbox = {
+# Necessary waydroid kernel config options (android app support)
+necessary_kconfig_options_waydroid = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "SQUASHFS": True,
             "SQUASHFS_XZ": True,
             "SQUASHFS_XATTR": True,
             "TMPFS_XATTR": True,
-            "ASHMEM": True,
             "ANDROID_BINDER_IPC": True,
             "ANDROID_BINDERFS": False,
-            "ANDROID_BINDER_DEVICES": ["binder", "hwbinder"],
+            "ANDROID_BINDER_DEVICES": ["binder", "hwbinder", "vndbinder"],
             "NETFILTER_XTABLES": True,
             "NETFILTER_XT_MATCH_COMMENT": True,
             "IP_NF_MANGLE": True,
@@ -354,35 +359,20 @@ necessary_kconfig_options_anbox = {
     },
     ">=3.5": {
         "all": {
-            "CROSS_MEMORY_ATTACH": True,  # required by Waydroid
+            "CROSS_MEMORY_ATTACH": True,
         }
     },
     ">=4.20.0": {
         "all": {
-            "PSI": True,  # required by userspace OOM killer in Waydroid
+            "PSI": True,  # required by userspace OOM killer
             "PSI_DEFAULT_DISABLED": False,
         }
-    }
-}
-
-# Necessary apparmor kernel config options (mandatory access control)
-# LSM: the value that "config LSM" sets in security/Kconfig, if
-# DEFAULT_SECURITY_APPARMOR is set (and other DEFAULT_SECURITY_* are unset).
-necessary_kconfig_options_apparmor = {
-    ">=0.0.0": {  # all versions
-        "all": {  # all arches
-            "AUDIT": True,
-            "DEFAULT_SECURITY_APPARMOR": True,
-            "LSM": "landlock,lockdown,yama,loadpin,safesetid,integrity,"
-                   "apparmor,selinux,smack,tomoyo,bpf",
-            "SECURITY_APPARMOR": True,
-        },
     },
-    "<5.1": {
+    "<5.18": {  # option has been dropped
         "all": {
-            "SECURITY_APPARMOR_BOOTPARAM_VALUE": True,
-        },
-    },
+            "ASHMEM": True,
+        }
+    }
 }
 
 # Necessary iwd kernel config options (inet wireless daemon)
@@ -422,7 +412,6 @@ necessary_kconfig_options_nftables = {
             "NF_TABLES": True,
             "NF_TABLES_INET": True,
             "NFT_CT": True,
-            "NFT_COUNTER": True,
             "NFT_LOG": True,
             "NFT_LIMIT": True,
             "NFT_MASQ": True,
@@ -442,6 +431,11 @@ necessary_kconfig_options_nftables = {
             "IP6_NF_NAT": True,
         }
     },
+    ">=3.13.0 <5.17": {  # option has been dropped
+        "all": {  # all arches
+            "NFT_COUNTER": True,
+        },
+    },
 }
 
 # Necessary kernel config options for containers (lxc, Docker)
@@ -461,7 +455,7 @@ necessary_kconfig_options_containers = {
             "CPUSETS": True,
             "KEYS": True,
             "VETH": True,
-            "BRIDGE": True,  # (also needed for anbox)
+            "BRIDGE": True,  # (also needed for waydroid)
             "BRIDGE_NETFILTER": True,
             "IP_NF_FILTER": True,
             "IP_NF_TARGET_MASQUERADE": True,
@@ -506,14 +500,19 @@ necessary_kconfig_options_containers = {
     ">=3.6": {
         "all": {  # all arches
             "MEMCG": True,
-            "MEMCG_SWAP": True,
             "DM_THIN_PROVISIONING": True,  # Storage Drivers
+            "SWAP": True,
         },
         "x86 x86_64": {  # only for x86, x86_64 (and sparc64, ia64)
-            "CONFIG_HUGETLB_PAGE": True,
+            "HUGETLB_PAGE": True,
             "CGROUP_HUGETLB": True,  # Optional section
         }
     },
+    ">=3.6 <6.1": {  # option has been dropped
+        "all": {
+            "MEMCG_SWAP": True,
+        }
+    },
     ">=3.7 <5.0": {
         "all": {
             "NF_NAT_IPV4": True,  # Needed for lxc
@@ -528,7 +527,7 @@ necessary_kconfig_options_containers = {
     },
     ">=3.9": {
         "all": {  # all arches
-            "BRIDGE_VLAN_FILTERING": True,  # Network Drivers (also for anbox)
+            "BRIDGE_VLAN_FILTERING": True,  # Network Drivers (also for waydroid)
             "MACVLAN": True,  # Network Drivers
         }
     },
@@ -577,6 +576,22 @@ necessary_kconfig_options_netboot = {
     },
 }
 
+# Necessary UEFI boot config options
+necessary_kconfig_options_uefi = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "EFI_STUB": True,
+            "EFI": True,
+            "DMI": True,
+            "EFI_ESRT": True,
+            "EFI_VARS_PSTORE": True,
+            "EFI_PARAMS_FROM_FDT": True,
+            "EFI_RUNTIME_WRAPPERS": True,
+            "EFI_GENERIC_STUB": True,
+        }
+    },
+}
+
 #
 # PARSE
 #
@@ -588,6 +603,7 @@ apkbuild_package_attributes = {
     "provides": {"array": True},
     "provider_priority": {"int": True},
     "install": {"array": True},
+    "triggers": {"array": True},
 
     # UI meta-packages can specify apps in "_pmb_recommends" to be explicitly
     # installed by default, and not implicitly as dependency of the UI meta-
@@ -643,15 +659,24 @@ apkbuild_attributes = {
     # git commit
     "_commit": {},
     "source": {"array": True},
+
+    # gcc
+    "_pkgbase": {},
+    "_pkgsnap": {}
 }
 
 # Reference: https://postmarketos.org/apkbuild-options
 apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
     "!pmb:kconfig-check",
-    "pmb:kconfigcheck-anbox",
+    "pmb:kconfigcheck-community",
     "pmb:kconfigcheck-containers",
+    "pmb:kconfigcheck-iwd",
+    "pmb:kconfigcheck-netboot",
     "pmb:kconfigcheck-nftables",
+    "pmb:kconfigcheck-uefi",
+    "pmb:kconfigcheck-waydroid",
+    "pmb:kconfigcheck-zram",
     "pmb:cross-native",
     "pmb:gpu-accel",
     "pmb:strict",
@@ -696,10 +721,13 @@ deviceinfo_attributes = [
     "generate_legacy_uboot_initfs",
     "kernel_cmdline",
     "generate_bootimg",
+    "header_version",
     "bootimg_qcdt",
     "bootimg_mtk_mkimage",
     "bootimg_dtb_second",
+    "bootimg_custom_args",
     "flash_offset_base",
+    "flash_offset_dtb",
     "flash_offset_kernel",
     "flash_offset_ramdisk",
     "flash_offset_second",
@@ -707,6 +735,7 @@ deviceinfo_attributes = [
     "flash_pagesize",
     "flash_fastboot_max_size",
     "flash_sparse",
+    "flash_sparse_samsung_format",
     "rootfs_image_sector_size",
     "sd_embed_firmware",
     "sd_embed_firmware_step_size",
@@ -800,7 +829,7 @@ uuu specific: $UUU_SCRIPT
 """
 flashers = {
     "fastboot": {
-        "depends": ["android-tools", "avbtool"],
+        "depends": [],  # pmaports.cfg: supported_fastboot_depends
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
             "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
@@ -877,7 +906,10 @@ flashers = {
                     "--padding_size", "$FLASH_PAGESIZE",
                     "--output", "/vbmeta.img"],
                 ["heimdall", "flash", "--$PARTITION_VBMETA", "/vbmeta.img"],
-                ["rm", "-f", "/vbmeta.img"]]
+                ["rm", "-f", "/vbmeta.img"]],
+            "flash_lk2nd": [
+                ["heimdall_wait_for_device.sh"],
+                ["heimdall", "flash", "--$PARTITION_KERNEL", "$BOOT/lk2nd.img"]]
         },
     },
     "adb": {
@@ -982,9 +1014,15 @@ newapkbuild_arguments_switches_other = [
 # Patterns of package names to ignore for automatic pmaport upgrading
 # ("pmbootstrap aportupgrade --all")
 upgrade_ignore = ["device-*", "firmware-*", "linux-*", "postmarketos-*",
-                  "*-aarch64", "*-armhf", "*-armv7"]
+                  "*-aarch64", "*-armhf", "*-armv7", "*-riscv64"]
 
 #
 # SIDELOAD
 #
 sideload_sudo_prompt = "[sudo] password for %u@%h: "
+
+#
+# CI
+#
+# Valid options für 'pmbootstrap ci', see https://postmarketos.org/pmb-ci
+ci_valid_options = ["native", "slow"]
