@@ -1,12 +1,12 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-import pmb.config
 import pmb.chroot.apk
+import pmb.config
+import pmb.config.pmaports
 import pmb.helpers.mount
 
 
-def init(args):
-    # Validate method
+def install_depends(args):
     if hasattr(args, 'flash_method'):
         method = args.flash_method or args.deviceinfo["flash_method"]
     else:
@@ -20,10 +20,20 @@ def init(args):
                            "Make sure, it is packaged for Alpine Linux, or"
                            " package it yourself, and then add it to"
                            " pmb/config/__init__.py.")
-    cfg = pmb.config.flashers[method]
+    depends = pmb.config.flashers[method]["depends"]
 
-    # Install depends
-    pmb.chroot.apk.install(args, cfg["depends"])
+    # Depends for some flash methods may be different for various pmaports
+    # branches, so read them from pmaports.cfg.
+    if method == "fastboot":
+        pmaports_cfg = pmb.config.pmaports.read_config(args)
+        depends = pmaports_cfg.get("supported_fastboot_depends",
+                                   "android-tools,avbtool").split(",")
+
+    pmb.chroot.apk.install(args, depends)
+
+
+def init(args):
+    install_depends(args)
 
     # Mount folders from host system
     for folder in pmb.config.flash_mount_bind:
