@@ -23,6 +23,26 @@ import pmb.helpers.pmaports
     See pmb/helpers/args.py for more information about the args variable. """
 
 
+def toggle_other_boolean_flags(*other_destinations, value=True):
+    """ Helper function to group several argparse flags to one. Sets multiple
+        other_destination to value.
+
+        :param other_destinations: 'the other argument names' str
+        :param value 'the value to set the other_destinations to' bool
+        :returns custom Action"""
+
+    class SetOtherDestinationsAction(argparse.Action):
+        def __init__(self, option_strings, dest, **kwargs):
+            super().__init__(option_strings, dest, nargs=0, const=value,
+                             default=value, **kwargs)
+
+        def __call__(self, parser, namespace, values, option_string=None):
+            for destination in other_destinations:
+                setattr(namespace, destination, value)
+
+    return SetOtherDestinationsAction
+
+
 def type_ondev_cp(val):
     """ Parse and validate arguments to 'pmbootstrap install --ondev --cp'.
 
@@ -444,10 +464,8 @@ def arguments_kconfig(subparser):
     check.add_argument("--arch", choices=arch_choices, dest="arch")
     check.add_argument("--file", action="store_true", help="check a file"
                        " directly instead of a config in a package")
-    check.add_argument("--anbox", action="store_true", help="check"
-                       " options needed for anbox too")
-    check.add_argument("--apparmor", action="store_true", help="check"
-                       " options needed for apparmor too")
+    check.add_argument("--waydroid", action="store_true", help="check"
+                       " options needed for waydroid too")
     check.add_argument("--iwd", action="store_true", help="check"
                        " options needed for iwd too")
     check.add_argument("--nftables", action="store_true", help="check"
@@ -457,7 +475,12 @@ def arguments_kconfig(subparser):
     check.add_argument("--zram", action="store_true", help="check"
                        " options needed for zram support too")
     check.add_argument("--netboot", action="store_true", help="check"
-                       " options needed for netboooting too")
+                       " options needed for netbooting too")
+    check.add_argument("--community", action="store_true", help="check"
+                       " options needed for various features, required for"
+                       " community/main devices")
+    check.add_argument("--uefi", action="store_true", help="check"
+                       " options needed for uefi too")
     add_kernel_arg(check)
 
     # "pmbootstrap kconfig edit"
@@ -523,6 +546,19 @@ def arguments_netboot(subparser):
     return ret
 
 
+def arguments_ci(subparser):
+    ret = subparser.add_parser("ci", help="run continuous integration scripts"
+                                          " locally of git repo in current"
+                                          " directory")
+    ret.add_argument("-a", "--all", action="store_true",
+                     help="name of the CI script to run, depending on the git"
+                          " repository")
+    ret.add_argument("scripts", nargs="*", metavar="script",
+                     help="name of the CI script to run, depending on the git"
+                          " repository")
+    return ret
+
+
 def package_completer(prefix, action, parser=None, parsed_args=None):
     args = parsed_args
     pmb.config.merge_with_args(args)
@@ -670,6 +706,7 @@ def arguments():
     arguments_newapkbuild(sub)
     arguments_lint(sub)
     arguments_status(sub)
+    arguments_ci(sub)
 
     # Action: log
     log = sub.add_parser("log", help="follow the pmbootstrap logfile")
@@ -707,6 +744,16 @@ def arguments():
     zap.add_argument("-r", "--rust", action="store_true",
                      help="also delete rust related caches")
 
+    zap_all_delete_args = ["http", "distfiles", "pkgs_local",
+                           "pkgs_local_mismatch", "netboot", "pkgs_online_mismatch",
+                           "rust"]
+    zap_all_delete_args_print = [arg.replace("_", "-")
+                                 for arg in zap_all_delete_args]
+    zap.add_argument("-a", "--all",
+                     action=toggle_other_boolean_flags(*zap_all_delete_args),
+                     help="delete everything, equivalent to: "
+                     f"--{' --'.join(zap_all_delete_args_print)}")
+
     # Action: stats
     stats = sub.add_parser("stats", help="show ccache stats")
     stats.add_argument("--arch", default=arch_native, choices=arch_choices)
@@ -808,7 +855,7 @@ def arguments():
                        dest="no_depends")
     build.add_argument("--envkernel", action="store_true",
                        help="Create an apk package from the build output of"
-                       " a kernel compiled with envkernel.sh.")
+                       " a kernel compiled locally on the host or with envkernel.sh.")
     add_packages_arg(build, nargs="+")
 
     # Action: deviceinfo_parse
